==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/es-ES/localizations.php <==
<?php

return [

    'select_language' => 'Seleccione un idioma',
    'languages' => [
        'en-US'=> 'Inglés, EEUU',
        'en-GB'=> 'Inglés, Reino Unido',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaans',
        'ar-SA'=> 'Árabe',
        'bg-BG'=> 'Búlgaro',
        'zh-CN'=> 'Chino simplificado',
        'zh-TW'=> 'Chino tradicional',
        'ca-ES' => 'Catalán',
        'hr-HR'=> 'Croata',
        'cs-CZ'=> 'Checo',
        'da-DK'=> 'Danés',
        'nl-NL'=> 'Holandés',
        'en-ID'=> 'inglés de Indonesia',
        'et-EE'=> 'Estonio',
        'fil-PH'=> 'Filipino',
        'fi-FI'=> 'Finlandés',
        'fr-FR'=> 'Francés',
        'de-DE'=> 'Alemán',
        'de-if'=> 'Alemán (informal)',
        'el-GR'=> 'Griego',
        'he-IL'=> 'Hebreo',
        'hu-HU'=> 'Húngaro',
        'is-IS' => 'Islandés',
        'id-ID'=> 'Indonesio',
        'ga-IE'=> 'Irlandés',
        'it-IT'=> 'Italiano',
        'ja-JP'=> 'Japonés',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Coreano',
        'lt-LT'=>'Lituano',
        'lv-LV'=> 'Letón',
        'mk-MK'=> 'Macedonio',
        'ms-MY'=> 'Malayo',
        'mi-NZ'=> 'Maorí',
        'mn-MN'=> 'Mongol',
        'no-NO'=> 'Noruego',
        'fa-IR'=> 'Persa',
        'pl-PL'=> 'Polaco',
        'pt-PT'=> 'Portugués',
        'pt-BR'=> 'Portugués, Brasileño',
        'ro-RO'=> 'Rumano',
        'ru-RU'=> 'Ruso',
        'sr-CS' => 'Serbio (Latino)',
        'sk-SK'=> 'Eslovaco',
        'sl-SI'=> 'Esloveno',
        'es-ES'=> 'Español',
        'es-CO'=> 'Español, Colombia',
        'es-MX'=> 'Español, México',
        'es-VE'=> 'Español, Venezuela',
        'sv-SE'=> 'Sueco',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Tailandés',
        'tr-TR'=> 'Turco',
        'uk-UA'=> 'Ucraniano',
        'vi-VN'=> 'Vietnamita',
        'cy-GB'=> 'Galés',
        'zu-ZA'=> 'Zulú',
    ],

    'select_country' => 'Seleccione un país',
    
    'countries' => [
        'AC'=>'Isla de Ascensión',
        'AD'=>'Andorra',
        'AE'=>'Emiratos Árabes Unidos',
        'AF'=>'Afganistán',
        'AG'=>'Antigua y Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'Antillas Holandesas',
        'AO'=>'Angola',
        'AQ'=>'La Antártida',
        'AR'=>'Argentina',
        'AS'=>'Samoa Americana',
        'AT'=>'Austria',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Åland',
        'AZ'=>'Azerbaiyán',
        'BA'=>'Bosnia y Herzegovina',
        'BB'=>'Barbados',
        'BE'=>'Bélgica',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaria',
        'BH'=>'Bahréin',
        'BI'=>'Burundi',
        'BJ'=>'Benín',
        'BM'=>'Bermuda',
        'BN'=>'Brunei',
        'BO'=>'Bolivia',
        'BR'=>'Brasil',
        'BS'=>'Bahamas',
        'BT'=>'Bután',
        'BV'=>'Isla Bouvet',
        'BW'=>'Botswana',
        'BY'=>'Bielorrusia',
        'BZ'=>'Belice',
        'CA'=>'Canadá',
        'CC'=>'Islas Cocos (Keeling)',
        'CD'=>'Congo (República Democrática del)',
        'CF'=>'República Centroafricana',
        'CG'=>'Congo (República del)',
        'CH'=>'Suiza',
        'CI'=>'Costa de Marfil',
        'CK'=>'Islas Cook',
        'CL'=>'Chile',
        'CM'=>'Camerún',
        'CN'=>'República Popular China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Cabo Verde',
        'CX'=>'Isla de Navidad',
        'CY'=>'Chipre',
        'CZ'=>'República Checa',
        'DE'=>'Alemania',
        'DJ'=>'Yibuti',
        'DK'=>'Dinamarca',
        'DM'=>'Dominica',
        'DO'=>'República Dominicana',
        'DZ'=>'Argelia',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Egipto',
        'ER'=>'Eritrea',
        'ES'=>'España',
        'ET'=>'Etiopía',
        'EU'=>'Unión Europea',
        'FI'=>'Finlandia',
        'FJ'=>'Fiji',
        'FK'=>'Islas Malvinas (Falkland)',
        'FM'=>'Estados Federados de la Micronesia',
        'FO'=>'Islas Faroe',
        'FR'=>'Francia',
        'GA'=>'Gabón',
        'GD'=>'Granada',
        'GE'=>'Georgia',
        'GF'=>'Guayana Francesa',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Groenlandia',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadalupe',
        'GQ'=>'Guinea Ecuatorial',
        'GR'=>'Grecia',
        'GS'=>'Islas Georgia del Sur y Sandwich del Sur',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Islas Heard y Mc Donald',
        'HN'=>'Honduras',
        'HR'=>'Croacia (nombre local: Hrvatska)',
        'HT'=>'Haití',
        'HU'=>'Hungría',
        'ID'=>'Indonesia',
        'IE'=>'Irlanda',
        'IL'=>'Israel',
        'IM'=>'Isla de Man',
        'IN'=>'India',
        'IO'=>'Territorio británico del océano Índico',
        'IQ'=>'Irak',
        'IR'=>'Irán, República Islámica Del',
        'IS'=>'Islandia',
        'IT'=>'Italia',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordania',
        'JP'=>'Japón',
        'KE'=>'Kenia',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Camboya',
        'KI'=>'Kiribati',
        'KM'=>'Islas Comoros',
        'KN'=>'San Cristóbal y Nevis',
        'KR'=>'Corea, República de',
        'KW'=>'Kuwait',
        'KY'=>'Islas Caimán',
        'KZ'=>'Kazajistán',
        'LA'=>'República Democrática Popular de Laos',
        'LB'=>'Líbano',
        'LC'=>'Santa Lucía',
        'LI'=>'Principado de Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesoto',
        'LT'=>'Lituania',
        'LU'=>'Luxemburgo',
        'LV'=>'Letonia',
        'LY'=>'Libia',
        'MA'=>'Marruecos',
        'MC'=>'Mónaco',
        'MD'=>'Moldova, República de',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Islas Marshall',
        'MK'=>'Macedonia, Ex República Yugoslava de',
        'ML'=>'Malí',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Macao',
        'MP'=>'Islas Marianas del Norte',
        'MQ'=>'Martinica',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauricio',
        'MV'=>'Maldivas',
        'MW'=>'Malawi',
        'MX'=>'México',
        'MY'=>'Malasia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'Nueva Caledonia',
        'NE'=>'Níger',
        'NF'=>'Isla Norfolk',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Países Bajos',
        'NO'=>'Noruega',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'Nueva Zelanda',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Perú',
        'PF'=>'Polinesia Francesa',
        'PG'=>'Papúa Nueva Guinea',
        'PH'=>'Filipinas, República de las',
        'PK'=>'Pakistán',
        'PL'=>'Polonia',
        'PM'=>'San Pedro y Miquelón',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestina',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Catar',
        'RE'=>'Reunión',
        'RO'=>'Rumania',
        'RS'=>'Serbia',
        'RU'=>'Federación Rusa',
        'RW'=>'Ruanda',
        'SA'=>'Arabia Saudita',
        'UK'=>'Escocia',
        'SB'=>'Islas Salomón',
        'SC'=>'Seychelles',
        'SS'=>'Sudán del Sur',
        'SD'=>'Sudán',
        'SE'=>'Suecia',
        'SG'=>'Singapur',
        'SH'=>'St. Helena',
        'SI'=>'Eslovenia',
        'SJ'=>'Islas Svalbard y Jan Mayen',
        'SK'=>'Eslovaquia (República Eslovaca)',
        'SL'=>'Sierra Leona',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Suriname',
        'ST'=>'Santo Tomé y Príncipe',
        'SU'=>'Unión Soviética',
        'SV'=>'El Salvador',
        'SY'=>'República Árabe Siria',
        'SZ'=>'Swaziland',
        'TC'=>'Islas Turcas y Caicos',
        'TD'=>'Chad',
        'TF'=>'Territorios Franceses del Sur',
        'TG'=>'Togo',
        'TH'=>'Tailandia',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'Timor Oriental',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'Timor Oriental (código antiguo)',
        'TR'=>'Turquía',
        'TT'=>'Trinidad y Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwán',
        'TZ'=>'Tanzania, República Unida de',
        'UA'=>'Ucrania',
        'UG'=>'Uganda',
        'UK'=>'Reino Unido',
        'US'=>'Estados Unidos',
        'UM'=>'Islas Ultramarinas Menores de Estados Unidos',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistán',
        'VA'=>'Estado de Vatican (Santa Sede)',
        'VC'=>'San Vicente y las Granadinas',
        'VE'=>'Venezuela',
        'VG'=>'Islas Vírgenes Británicas',
        'VI'=>'Islas Vírgenes (EE. UU.)',
        'VN'=>'Vietnam',
        'VU'=>'Vanuatu',
        'WF'=>'Islas Wallis y Futuna',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'Sudáfrica',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabue',
    ],
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/es-ES/localizations.php <==
<?php

return [

    'select_language' => 'Seleccionar un idioma',
    'languages' => [
        'en-US'=> 'Inglés, EEUU',
        'en-GB'=> 'Inglés, Reino Unido',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaans',
        'ar-SA'=> 'Árabe',
        'bg-BG'=> 'Búlgaro',
        'zh-CN'=> 'Chino simplificado',
        'zh-TW'=> 'Chino tradicional',
        'ca-ES' => 'Catalán',
        'hr-HR'=> 'Croata',
        'cs-CZ'=> 'Checo',
        'da-DK'=> 'Danés',
        'nl-NL'=> 'Holandés',
        'en-ID'=> 'inglés de Indonesia',
        'et-EE'=> 'Estonio',
        'fil-PH'=> 'Filipino',
        'fi-FI'=> 'Finlandés',
        'fr-FR'=> 'Francés',
        'de-DE'=> 'Alemán',
        'de-if'=> 'Alemán (informal)',
        'el-GR'=> 'Griego',
        'he-IL'=> 'Hebreo',
        'hu-HU'=> 'Húngaro',
        'is-IS' => 'Islandés',
        'id-ID'=> 'Indonesio',
        'ga-IE'=> 'Irlandés',
        'it-IT'=> 'Italiano',
        'ja-JP'=> 'Japonés',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Coreano',
        'lt-LT'=>'Lituano',
        'lv-LV'=> 'Letón',
        'mk-MK'=> 'Macedonio',
        'ms-MY'=> 'Malayo',
        'mi-NZ'=> 'Maorí',
        'mn-MN'=> 'Mongol',
        'no-NO'=> 'Noruego',
        'fa-IR'=> 'Persa',
        'pl-PL'=> 'Polaco',
        'pt-PT'=> 'Portugués',
        'pt-BR'=> 'Portugués, Brasileño',
        'ro-RO'=> 'Rumano',
        'ru-RU'=> 'Ruso',
        'sr-CS' => 'Serbio (Latino)',
        'sk-SK'=> 'Eslovaco',
        'sl-SI'=> 'Esloveno',
        'so-SO'=> 'Somali',
        'es-ES'=> 'Español',
        'es-CO'=> 'Español, Colombia',
        'es-MX'=> 'Español, México',
        'es-VE'=> 'Español, Venezuela',
        'sv-SE'=> 'Sueco',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Tailandés',
        'tr-TR'=> 'Turco',
        'uk-UA'=> 'Ucraniano',
        'vi-VN'=> 'Vietnamita',
        'cy-GB'=> 'Galés',
        'zu-ZA'=> 'Zulú',
    ],

    'select_country' => 'Seleccionar un país',
    
    'countries' => [
        'AC'=>'Isla de Ascensión',
        'AD'=>'Andorra',
        'AE'=>'Emiratos Árabes Unidos',
        'AF'=>'Afganistán',
        'AG'=>'Antigua y Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'Antillas Holandesas',
        'AO'=>'Angola',
        'AQ'=>'La Antártida',
        'AR'=>'Argentina',
        'AS'=>'Samoa Americana',
        'AT'=>'Austria',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Åland',
        'AZ'=>'Azerbaiyán',
        'BA'=>'Bosnia y Herzegovina',
        'BB'=>'Barbados',
        'BE'=>'Bélgica',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaria',
        'BH'=>'Baréin',
        'BI'=>'Burundi',
        'BJ'=>'Benín',
        'BM'=>'Bermuda',
        'BN'=>'Brunei',
        'BO'=>'Bolivia',
        'BR'=>'Brasil',
        'BS'=>'Bahamas',
        'BT'=>'Bután',
        'BV'=>'Isla Bouvet',
        'BW'=>'Botswana',
        'BY'=>'Bielorrusia',
        'BZ'=>'Belice',
        'CA'=>'Canadá',
        'CC'=>'Islas Cocos (Keeling)',
        'CD'=>'Congo (República Democrática del)',
        'CF'=>'República Centroafricana',
        'CG'=>'Congo (República del)',
        'CH'=>'Suiza',
        'CI'=>'Costa de Marfil',
        'CK'=>'Islas Cook',
        'CL'=>'Chile',
        'CM'=>'Camerún',
        'CN'=>'República Popular China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Cabo Verde',
        'CX'=>'Isla de Navidad',
        'CY'=>'Chipre',
        'CZ'=>'República Checa',
        'DE'=>'Alemania',
        'DJ'=>'Yibuti',
        'DK'=>'Dinamarca',
        'DM'=>'Dominica',
        'DO'=>'República Dominicana',
        'DZ'=>'Argelia',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Egipto',
        'ER'=>'Eritrea',
        'ES'=>'España',
        'ET'=>'Etiopía',
        'EU'=>'Unión Europea',
        'FI'=>'Finlandia',
        'FJ'=>'Fiji',
        'FK'=>'Islas Malvinas (Falkland)',
        'FM'=>'Estados Federados de la Micronesia',
        'FO'=>'Islas Faroe',
        'FR'=>'Francia',
        'GA'=>'Gabón',
        'GD'=>'Granada',
        'GE'=>'Georgia',
        'GF'=>'Guayana Francesa',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Groenlandia',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadalupe',
        'GQ'=>'Guinea Ecuatorial',
        'GR'=>'Grecia',
        'GS'=>'Islas Georgia del Sur y Sandwich del Sur',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Islas Heard y Mc Donald',
        'HN'=>'Honduras',
        'HR'=>'Croacia (nombre local: Hrvatska)',
        'HT'=>'Haití',
        'HU'=>'Hungría',
        'ID'=>'Indonesia',
        'IE'=>'Irlanda',
        'IL'=>'Israel',
        'IM'=>'Isla de Man',
        'IN'=>'India',
        'IO'=>'Territorio británico del océano Índico',
        'IQ'=>'Irak',
        'IR'=>'Irán, República Islámica Del',
        'IS'=>'Islandia',
        'IT'=>'Italia',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordania',
        'JP'=>'Japón',
        'KE'=>'Kenia',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Camboya',
        'KI'=>'Kiribati',
        'KM'=>'Islas Comoros',
        'KN'=>'San Cristóbal y Nevis',
        'KR'=>'Corea, República de',
        'KW'=>'Kuwait',
        'KY'=>'Islas Caimán',
        'KZ'=>'Kazajistán',
        'LA'=>'República Democrática Popular de Laos',
        'LB'=>'Líbano',
        'LC'=>'Santa Lucía',
        'LI'=>'Principado de Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesoto',
        'LT'=>'Lituania',
        'LU'=>'Luxemburgo',
        'LV'=>'Letonia',
        'LY'=>'Libia',
        'MA'=>'Marruecos',
        'MC'=>'Mónaco',
        'MD'=>'Moldova, República de',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Islas Marshall',
        'MK'=>'Macedonia, Ex República Yugoslava de',
        'ML'=>'Malí',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Macao',
        'MP'=>'Islas Marianas del Norte',
        'MQ'=>'Martinica',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauricio',
        'MV'=>'Maldivas',
        'MW'=>'Malawi',
        'MX'=>'México',
        'MY'=>'Malasia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'Nueva Caledonia',
        'NE'=>'Níger',
        'NF'=>'Isla Norfolk',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Países Bajos',
        'NO'=>'Noruega',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'Nueva Zelanda',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Perú',
        'PF'=>'Polinesia Francesa',
        'PG'=>'Papúa Nueva Guinea',
        'PH'=>'Filipinas, República de las',
        'PK'=>'Pakistán',
        'PL'=>'Polonia',
        'PM'=>'San Pedro y Miquelón',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestina',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Catar',
        'RE'=>'Reunión',
        'RO'=>'Rumania',
        'RS'=>'Serbia',
        'RU'=>'Federación Rusa',
        'RW'=>'Ruanda',
        'SA'=>'Arabia Saudita',
        'UK'=>'Escocia',
        'SB'=>'Islas Salomón',
        'SC'=>'Seychelles',
        'SS'=>'Sudán del Sur',
        'SD'=>'Sudán',
        'SE'=>'Suecia',
        'SG'=>'Singapur',
        'SH'=>'St. Helena',
        'SI'=>'Eslovenia',
        'SJ'=>'Islas Svalbard y Jan Mayen',
        'SK'=>'Eslovaquia (República Eslovaca)',
        'SL'=>'Sierra Leona',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Suriname',
        'ST'=>'Santo Tomé y Príncipe',
        'SU'=>'Unión Soviética',
        'SV'=>'El Salvador',
        'SY'=>'República Árabe Siria',
        'SZ'=>'Swaziland',
        'TC'=>'Islas Turcas y Caicos',
        'TD'=>'Chad',
        'TF'=>'Territorios Franceses del Sur',
        'TG'=>'Togo',
        'TH'=>'Tailandia',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'Timor Oriental',
        'TM'=>'Turkmenistán',
        'TN'=>'Túnez',
        'TO'=>'Tonga',
        'TP'=>'Timor Oriental (código antiguo)',
        'TR'=>'Turquía',
        'TT'=>'Trinidad y Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwán',
        'TZ'=>'Tanzania, República Unida de',
        'UA'=>'Ucrania',
        'UG'=>'Uganda',
        'UK'=>'Reino Unido',
        'US'=>'Estados Unidos',
        'UM'=>'Islas Ultramarinas Menores de Estados Unidos',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistán',
        'VA'=>'Estado de Vatican (Santa Sede)',
        'VC'=>'San Vicente y las Granadinas',
        'VE'=>'Venezuela',
        'VG'=>'Islas Vírgenes Británicas',
        'VI'=>'Islas Vírgenes (EE. UU.)',
        'VN'=>'Vietnam',
        'VU'=>'Vanuatu',
        'WF'=>'Islas Wallis y Futuna',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'Sudáfrica',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabue',
    ],
];
